;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cort" "20260516.316"
  "Simplify extended unit test framework."
  '((emacs  "24.1")
    (ansi   "0.4")
    (cl-lib "0.6"))
  :url "https://github.com/conao3/cort.el"
  :commit "c07ff17c097e3f524751ffb61105ef4704593570"
  :revdesc "c07ff17c097e"
  :keywords '("test" "lisp")
  :authors '(("Naoya Yamashita" . "conao3@gmail.com"))
  :maintainers '(("Naoya Yamashita" . "conao3@gmail.com")))
